powered by
Correct data by setting all latent factors to their median values and reversing the regression model
correct(x, data = "y", cell_attr = x$cell_attr, do_round = TRUE, do_pos = TRUE, show_progress = TRUE)
A list that provides model parameters and optionally meta data; use output of vst function
The name of the entry in x that holds the data
Provide cell meta data holding latent data info
Round the result to integers
Set negative values in the result to zero
Whether to print progress bar
Corrected data as UMI counts
# NOT RUN { vst_out <- vst(pbmc, return_cell_attr = TRUE) umi_corrected <- correct(vst_out) # } # NOT RUN { # }
Run the code above in your browser using DataLab